Stan Math Library: stan/math/prim/mat/prob/gaussian_dlm_obs_log.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
gaussian_dlm_obs_log.hpp File Reference
`#include <boost/random/normal_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/mat/err/check_cov_matrix.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/mat/err/check_spsd_matrix.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_nonnegative.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/mat/fun/add.hpp>`
`#include <stan/math/prim/mat/fun/dot_product.hpp>`
`#include <stan/math/prim/mat/fun/inverse_spd.hpp>`
`#include <stan/math/prim/mat/fun/log.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant_spd.hpp>`
`#include <stan/math/prim/mat/fun/multiply.hpp>`
`#include <stan/math/prim/mat/fun/quad_form.hpp>`
`#include <stan/math/prim/mat/fun/quad_form_sym.hpp>`
`#include <stan/math/prim/mat/fun/subtract.hpp>`
`#include <stan/math/prim/mat/fun/tcrossprod.hpp>`
`#include <stan/math/prim/mat/fun/trace_quad_form.hpp>`
`#include <stan/math/prim/mat/fun/transpose.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<bool propto, typename T_y , typename T_F , typename T_G , typename T_V , typename T_W , typename T_m0 , typename T_C0 >
return_type< T_y, typename return_type< T_F, T_G, T_V, T_W, T_m0, T_C0 >::type >::type | stan::math::gaussian_dlm_obs_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_F, Eigen::Dynamic, Eigen::Dynamic > &F, const Eigen::Matrix< T_G, Eigen::Dynamic, Eigen::Dynamic > &G, const Eigen::Matrix< T_V, Eigen::Dynamic, Eigen::Dynamic > &V, const Eigen::Matrix< T_W, Eigen::Dynamic, Eigen::Dynamic > &W, const Eigen::Matrix< T_m0, Eigen::Dynamic, 1 > &m0, const Eigen::Matrix< T_C0, Eigen::Dynamic, Eigen::Dynamic > &C0)
| The log of a Gaussian dynamic linear model (GDLM). More...
template<typename T_y , typename T_F , typename T_G , typename T_V , typename T_W , typename T_m0 , typename T_C0 >
return_type< T_y, typename return_type< T_F, T_G, T_V, T_W, T_m0, T_C0 >::type >::type | stan::math::gaussian_dlm_obs_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_F, Eigen::Dynamic, Eigen::Dynamic > &F, const Eigen::Matrix< T_G, Eigen::Dynamic, Eigen::Dynamic > &G, const Eigen::Matrix< T_V, Eigen::Dynamic, Eigen::Dynamic > &V, const Eigen::Matrix< T_W, Eigen::Dynamic, Eigen::Dynamic > &W, const Eigen::Matrix< T_m0, Eigen::Dynamic, 1 > &m0, const Eigen::Matrix< T_C0, Eigen::Dynamic, Eigen::Dynamic > &C0)
template<bool propto, typename T_y , typename T_F , typename T_G , typename T_V , typename T_W , typename T_m0 , typename T_C0 >
return_type< T_y, typename return_type< T_F, T_G, T_V, T_W, T_m0, T_C0 >::type >::type | stan::math::gaussian_dlm_obs_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_F, Eigen::Dynamic, Eigen::Dynamic > &F, const Eigen::Matrix< T_G, Eigen::Dynamic, Eigen::Dynamic > &G, const Eigen::Matrix< T_V, Eigen::Dynamic, 1 > &V, const Eigen::Matrix< T_W, Eigen::Dynamic, Eigen::Dynamic > &W, const Eigen::Matrix< T_m0, Eigen::Dynamic, 1 > &m0, const Eigen::Matrix< T_C0, Eigen::Dynamic, Eigen::Dynamic > &C0)
| The log of a Gaussian dynamic linear model (GDLM) with uncorrelated observation disturbances. More...
template<typename T_y , typename T_F , typename T_G , typename T_V , typename T_W , typename T_m0 , typename T_C0 >
return_type< T_y, typename return_type< T_F, T_G, T_V, T_W, T_m0, T_C0 >::type >::type | stan::math::gaussian_dlm_obs_log (const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y, const Eigen::Matrix< T_F, Eigen::Dynamic, Eigen::Dynamic > &F, const Eigen::Matrix< T_G, Eigen::Dynamic, Eigen::Dynamic > &G, const Eigen::Matrix< T_V, Eigen::Dynamic, 1 > &V, const Eigen::Matrix< T_W, Eigen::Dynamic, Eigen::Dynamic > &W, const Eigen::Matrix< T_m0, Eigen::Dynamic, 1 > &m0, const Eigen::Matrix< T_C0, Eigen::Dynamic, Eigen::Dynamic > &C0)

[ Stan Home Page ] © 2011–2016, Stan Development Team.